==> vue-1.0.9.tgz: package/lib/form.js <==
import { Form, usePlugin, setLicenseKey, } from '@forms.js/core';
import { defineComponent, h, isVNode } from 'vue';
const FormComponent = defineComponent({
    props: {
        options: {
            type: Object,
            required: true,
        },
        plugins: {
            type: Array,
            required: false,
            default: [],
        },
        licenseKey: {
            type: String,
            required: false,
            default: null,
        },
    },
    data() {
        return {
            formInstance: null,
            formData: null,
            assignedOptions: this.$props.options,
        };
    },
    methods: {
        reset() {
            var _a;
            (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.reset();
        },
        validate() {
            var _a;
            (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.validate();
        },
        submit() {
            var _a;
            (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.submit();
        },
        getForm() {
            return this.formInstance;
        },
        getField(id) {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getField(id);
        },
        getGroup(id) {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getGroup(id);
        },
        getGroups() {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getGroups();
        },
        getButton(id) {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getButton(id);
        },
        getButtons() {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getButtons();
        },
        getData() {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getData();
        },
        getId() {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getId();
        },
        getFormElement() {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getFormElement();
        },
        isValid() {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.isValid();
        },
        initForm() {
            var _a, _b, _c, _d, _e;
            this.assignedOptions = this.checkForVNodes(this.assignedOptions);
            this.formInstance = new Form(this.$el, this.assignedOptions);
            this.formData = (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getData();
            (_b = this.formInstance) === null || _b === void 0 ? void 0 : _b.on("submitted", () => {
                var _a, _b;
                this.$emit('submitted', (_b = (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getData()) !== null && _b !== void 0 ? _b : null);
            }, true);
            (_c = this.formInstance) === null || _c === void 0 ? void 0 : _c.on("resetted", () => {
                this.$emit('resetted');
            }, true);
            (_d = this.formInstance) === null || _d === void 0 ? void 0 : _d.on("dataUpdated", () => {
                var _a, _b, _c, _d;
                this.formData = (_b = (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getData()) !== null && _b !== void 0 ? _b : null;
                this.$emit('dataUpdated', (_d = (_c = this.formInstance) === null || _c === void 0 ? void 0 : _c.getData()) !== null && _d !== void 0 ? _d : null);
            }, true);
            (_e = this.formInstance) === null || _e === void 0 ? void 0 : _e.on("validationFailed", () => {
                this.$emit('validationFailed');
            }, true);
        },
        acceptVNodes(schema) {
            return schema.map((element) => {
                if (element.label && isVNode(element.label)) {
                    element.label = h(element.label);
                }
                if (element.template && isVNode(element.template)) {
                    element.template = function () {
                    };
                }
                if (element.schema) {
                    element = this.checkForVNodes(element);
                }
                return element;
            });
        },
        checkForVNodes(opt) {
            if (opt.schema) {
                opt.schema = this.acceptVNodes(opt.schema);
            }
            return opt;
        },
    },
    render() {
        return h('div');
    },
    mounted() {
        var _a;
        usePlugin((_a = this.$props.plugins) !== null && _a !== void 0 ? _a : []);
        if (this.$props.licenseKey) {
            setLicenseKey(this.$props.licenseKey);
        }
        this.initForm();
    },
    beforeUnmount() {
        var _a;
        (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.destroy();
    },
    watch: {
        options: {
            handler: function () {
                var _a;
                (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.destroy();
                this.initForm();
            },
            deep: true,
        },
    },
    emits: {
        submitted: (data) => true,
        resetted: () => true,
        dataUpdated: (data) => true,
        validationFailed: () => true,
    },
});
export default FormComponent;

==> vue-1.0.10.tgz: package/lib/form.js <==
import { Form, usePlugin, setLicenseKey, } from '@forms.js/core';
import { defineComponent, h } from 'vue';
const FormComponent = defineComponent({
    props: {
        options: {
            type: Object,
            required: true,
        },
        plugins: {
            type: Array,
            required: false,
            default: [],
        },
        licenseKey: {
            type: String,
            required: false,
            default: null,
        },
    },
    data() {
        return {
            formInstance: null,
            formData: null,
        };
    },
    methods: {
        reset() {
            var _a;
            (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.reset();
        },
        validate() {
            var _a;
            (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.validate();
        },
        submit() {
            var _a;
            (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.submit();
        },
        getForm() {
            return this.formInstance;
        },
        getField(id) {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getField(id);
        },
        getGroup(id) {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getGroup(id);
        },
        getGroups() {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getGroups();
        },
        getButton(id) {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getButton(id);
        },
        getButtons() {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getButtons();
        },
        getData() {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getData();
        },
        getId() {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getId();
        },
        getFormElement() {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getFormElement();
        },
        isValid() {
            var _a;
            return (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.isValid();
        },
        initForm() {
            var _a, _b, _c, _d, _e;
            this.formInstance = new Form(this.$el, this.$props.options);
            this.formData = (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getData();
            (_b = this.formInstance) === null || _b === void 0 ? void 0 : _b.on("submitted", () => {
                var _a, _b;
                this.$emit('submitted', (_b = (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getData()) !== null && _b !== void 0 ? _b : null);
            }, true);
            (_c = this.formInstance) === null || _c === void 0 ? void 0 : _c.on("resetted", () => {
                this.$emit('resetted');
            }, true);
            (_d = this.formInstance) === null || _d === void 0 ? void 0 : _d.on("dataUpdated", () => {
                var _a, _b, _c, _d;
                this.formData = (_b = (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.getData()) !== null && _b !== void 0 ? _b : null;
                this.$emit('dataUpdated', (_d = (_c = this.formInstance) === null || _c === void 0 ? void 0 : _c.getData()) !== null && _d !== void 0 ? _d : null);
            }, true);
            (_e = this.formInstance) === null || _e === void 0 ? void 0 : _e.on("validationFailed", () => {
                this.$emit('validationFailed');
            }, true);
        },
    },
    render() {
        return h('div');
    },
    mounted() {
        var _a;
        usePlugin((_a = this.$props.plugins) !== null && _a !== void 0 ? _a : []);
        if (this.$props.licenseKey) {
            setLicenseKey(this.$props.licenseKey);
        }
        this.initForm();
    },
    beforeUnmount() {
        var _a;
        (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.destroy();
    },
    watch: {
        options: {
            handler: function () {
                var _a;
                (_a = this.formInstance) === null || _a === void 0 ? void 0 : _a.destroy();
                this.initForm();
            },
            deep: true,
        },
    },
    emits: {
        submitted: (data) => true,
        resetted: () => true,
        dataUpdated: (data) => true,
        validationFailed: () => true,
    },
});
export default FormComponent;
